@@ -319,33 +319,9 @@ bool DstroyGame::init()
 	font.importFixedFont(true, 0, 8*7, 320, 8*7, 8, 8);
 
 
-#ifdef GP2X
-	if (TGIGlobals::bRotateScreen)
-	{
-		if (DstroyGame::params.nPlayers == 1)
-		{
-			loadCommands(DstroyGlobals::addResText("commandsgp2xr"));
-		}
-		else
-		{
-			loadCommands(DstroyGlobals::addResText("commandsgp2xr2"));
-		}
-	}
-	else
-	{
-		if (DstroyGame::params.nPlayers == 1)
-		{
-			loadCommands(DstroyGlobals::addResText("commandsgp2x"));
-		}
-		else
-		{
-			loadCommands(DstroyGlobals::addResText("commandsgp2x2"));
-		}
-	}
-#endif
-#ifdef DESKTOP
+
 	loadCommands(DstroyGlobals::addConfigText("commands"));
-#endif
+
 #ifdef __NDS__
 	TGIInputMessage message;
 	message.lId	= up;
@@ -375,6 +351,7 @@ bool DstroyGame::init()
 	message.sdlKey = KEY_A;
 	vecInputMessage.push_back(message);
 #endif
+
 	nLevelMinToQuePasa = 3;
 	nLevelMinFixedObjects = 0;
 
